﻿using System.Windows.Forms;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraEditors.Repository;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 저장소 항목 진행 바
        /// </summary>
        private RepositoryItemProgressBar repositoryItemProgressBar;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                true                            // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridControl.RepositoryItems.Add(this.repositoryItemProgressBar);

            this.gridControl.DataSource = new nwindDataSetTableAdapters.ProductsTableAdapter().GetData();

            this.repositoryItemProgressBar = new RepositoryItemProgressBar();

            this.repositoryItemProgressBar.Minimum = 0;
            this.repositoryItemProgressBar.Maximum = 200;

            this.gridView.Columns["UnitsInStock"].ColumnEdit = this.repositoryItemProgressBar;

            this.gridView.BestFitColumns();

            this.repositoryItemProgressBar.KeyPress += repositoryItemProgressBar_KeyPress;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 저장소 항목 진행 바 키 PRESS 처리하기 - repositoryItemProgressBar_KeyPress(sender, e)

        /// <summary>
        /// 저장소 항목 진행 바 키 PRESS 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void repositoryItemProgressBar_KeyPress(object sender, KeyPressEventArgs e)
        {
            int i = 0;

            if(this.gridView.ActiveEditor == null)
            {
                return;
            }

            if(e.KeyChar == '+')
            {
                i = (short)this.gridView.ActiveEditor.EditValue;

                if(i < 200)
                {
                    this.gridView.ActiveEditor.EditValue = (short)(i + 1);
                }
            }

            if(e.KeyChar == '-')
            {
                i = (short)this.gridView.ActiveEditor.EditValue;

                if(i > 0)
                {
                    this.gridView.ActiveEditor.EditValue = (short)(i - 1);
                }
            }
        }

        #endregion
    }
}